<style> 
    .comment__uuid__ {
        margin-left: 20%;
        margin-right: 20%;
        vertical-align: middle;
    }
    .left__uuid__ {
        float: left;
        width: 10%;
    }
    .left__uuid__ img {
        display: block;
        margin-left: auto;
        margin-right: auto;
    }
    .right__uuid__ {
        float: right;
        width: 88%;
        font-size: 10;
    }
</style>

<br/>
<br/>
<div class="comment__uuid__">
    <div class="left__uuid__">
        <img src="{{ img_logo }}" height="40" width="40"/>
    </div>
    <div class="right__uuid__">
        {{ comment }}
    </div>
</div>
